@@ -2,4 +2,7 @@
 
 __author__ = """James Irving"""
 __email__ = 'james.irving@flatironschool.com'
-__version__ = '0.1.0'
+__version__ = '0.1.1'
+
+import demo_package_041320pt.lz as imports
+import demo_package_041320pt.my_functions as mf
